@@ -7,7 +7,7 @@
 #' @export
 pkcov <-
 function(y, auc, doses, x, theta, deltaAUC, prob = 0.9, options = list(nchains = 4, niter = 4000, nadapt = 0.8), 
-             betapriors = c(-14.76, 3.23), thetaL=NULL, p0 = NULL, L = NULL){
+             betapriors = c(-14.76, 3.23), thetaL=NULL, p0 = NULL, L = NULL, CI = TRUE){
         
         checking1 <- function(x,target,error){
             sum(x>(target+error))/length(x)              ## how many x are greater than (target+error) / length(x) =  the probability
@@ -42,11 +42,15 @@ function(y, auc, doses, x, theta, deltaAUC, prob = 0.9, options = list(nchains =
         
         pstim_sum <- matrix(0, ncol = options$nchains*options$niter/2, nrow = length(doses))
         p_sum <- NULL
-        for(o in 1:length(doses)){
-            for(i in 1:ncol(pstim_sum)){
-                pstim_sum[o,i] <- 1 / (1 + exp(Beta0[i] + Beta1[i]*log(doses[o])))
+        if(CI == "TRUE"){
+            for(o in 1:length(doses)){
+                for(i in 1:ncol(pstim_sum)){
+                    pstim_sum[o,i] <- 1 / (1 + exp(Beta0[i] + Beta1[i]*log(doses[o])))
+                }
+                p_sum <- rbind(p_sum, summary(pstim_sum[o,]))
             }
-            p_sum <- rbind(p_sum, summary(pstim_sum[o,]))
+        }else{
+            p_sum <- NULL
         }
         
         pstop <-  checking1(pstim, target=theta, error=0)
